/*
 * 
 *  This file is part of XmlParser.
 *
 *  Foobar is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Foobar is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.sourceprojects.xmlparser;

import javax.xml.namespace.QName;

import org.sourceprojects.xmlparser.exceptions.XmlParserParsingException;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

/**
 * Abstract implementation of
 * {@link org.sourceprojects.xmlparser.TagDefinitionParser} with basic handling
 * of some of the needed method structures. If someone want's to implement a tag
 * parser / transformer, he must extends this class instead of implementing the
 * interface directly.
 * 
 * @author noctarius
 * @since 0.0.1
 * 
 * @param <B>
 *            Type of ContextObject to use
 */
public abstract class AbstractTagParser<B> implements TagDefinitionParser<B> {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.sourceprojects.xmlparser.TagDefinitionParser#parseElement(org.w3c
	 * .dom.Element, org.sourceprojects.xmlparser.ParserContext,
	 * org.sourceprojects.xmlparser.DefinitionBuilder)
	 */
	@Override
	public void parseElement(Element element, ParserContext<B> parserContext,
			DefinitionBuilder definitionBuilder)
			throws XmlParserParsingException {
		return;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.sourceprojects.xmlparser.TagDefinitionParser#parseElement(org.w3c
	 * .dom.Element, java.lang.String,
	 * org.sourceprojects.xmlparser.ParserContext,
	 * org.sourceprojects.xmlparser.DefinitionBuilder)
	 */
	@Override
	public void parseElement(Element element, String localName,
			ParserContext<B> parserContext, DefinitionBuilder definitionBuilder)
			throws XmlParserParsingException {
		parseElement(element, parserContext, definitionBuilder);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.sourceprojects.xmlparser.TagDefinitionParser#parseElement(org.w3c
	 * .dom.Element, java.lang.String, javax.xml.namespace.QName,
	 * org.sourceprojects.xmlparser.ParserContext,
	 * org.sourceprojects.xmlparser.DefinitionBuilder)
	 */
	@Override
	public void parseElement(Element element, String localName, QName parent,
			ParserContext<B> parserContext, DefinitionBuilder definitionBuilder)
			throws XmlParserParsingException {
		parseElement(element, localName, parserContext, definitionBuilder);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.sourceprojects.xmlparser.TagDefinitionParser#transformElement(org
	 * .w3c.dom.Element, org.sourceprojects.xmlparser.ParserContext,
	 * org.sourceprojects.xmlparser.DefinitionBuilder)
	 */
	@Override
	public Node transformElement(Element element,
			ParserContext<B> parserContext, DefinitionBuilder definitionBuilder)
			throws XmlParserParsingException {
		return definitionBuilder.getDocument().importNode(element, false);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.sourceprojects.xmlparser.TagDefinitionParser#transformElement(org
	 * .w3c.dom.Element, java.lang.String,
	 * org.sourceprojects.xmlparser.ParserContext,
	 * org.sourceprojects.xmlparser.DefinitionBuilder)
	 */
	@Override
	public Node transformElement(Element element, String localName,
			ParserContext<B> parserContext, DefinitionBuilder definitionBuilder)
			throws XmlParserParsingException {
		return transformElement(element, parserContext, definitionBuilder);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.sourceprojects.xmlparser.TagDefinitionParser#transformElement(org
	 * .w3c.dom.Element, java.lang.String, javax.xml.namespace.QName,
	 * org.sourceprojects.xmlparser.ParserContext,
	 * org.sourceprojects.xmlparser.DefinitionBuilder)
	 */
	@Override
	public Node transformElement(Element element, String localName,
			QName parent, ParserContext<B> parserContext,
			DefinitionBuilder definitionBuilder)
			throws XmlParserParsingException {
		return transformElement(element, localName, parserContext,
				definitionBuilder);
	}

}
