/*
 * 
 *  This file is part of XmlParser.
 *
 *  Foobar is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Foobar is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.sourceprojects.xmlparser;

import org.w3c.dom.ls.LSInput;

/**
 * Interface for NamespaceResolver implementations to resolve namespaces to
 * other URLs than the default ones. Used in standard implementation to redirect
 * input to bundled XML schemata instead of using online version to be able to
 * work in offline state
 * 
 * @author noctarius
 * @since 0.0.1
 */
public interface NamespaceResolver {

	/**
	 * Returns the namespace URI
	 * 
	 * @return Namespace URI as String
	 */
	String getNamespaceURI();

	/**
	 * Returns an implementation of {@link LSInput} for the queried namespace
	 * 
	 * @param type
	 *            Type of the namespace to resolve
	 * @param namespaceURI
	 *            Original namespace URI to resolve
	 * @param publicId
	 *            PublicId of the namespace
	 * @param systemId
	 *            Local SystemId of the namespace
	 * @param baseURI
	 *            Base URI of the namespace
	 * @return The Implementation of {@link LSInput}
	 */
	LSInput getInput(String type, String namespaceURI, String publicId,
			String systemId, String baseURI);
}
