/*
 * 
 *  This file is part of XmlParser.
 *
 *  Foobar is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Foobar is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.sourceprojects.xmlparser;

/**
 * Interface for ParserContext implementations.<br>
 * The standard implementation of this interface returned by
 * {@link XmlParserFactory} is generified to be able to meet users requirements
 * while parsing
 * 
 * @author noctarius
 * @since 0.0.1
 * 
 * @param <T>
 *            Type of ContextObject to use
 */
public interface ParserContext<T> {

	/**
	 * Sets the context object of type T for being available while parsing
	 * 
	 * @param contextObject
	 *            Instance of type T
	 */
	void setContextObject(T contextObject);

	/**
	 * Returns the context object of type T for being available while parsing
	 * 
	 * @return Instance of type T
	 */
	T getContextObject();

	/**
	 * Sets the state string to identify different states for parsing on same
	 * {@link TagDefinitionParser} implementations for all parsing reasons
	 * 
	 * @param parserState
	 *            String to identify a parser state
	 */
	void setParserState(String parserState);

	/**
	 * Returns the state string to identify different states of parsing on same
	 * {@link TagDefinitionParser} implementations for all parsing reasons
	 * 
	 * @return
	 */
	String getParserState();
}
