/*
 * 
 *  This file is part of XmlParser.
 *
 *  Foobar is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Foobar is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.sourceprojects.xmlparser;

import org.w3c.dom.ls.LSResourceResolver;

/**
 * Interface to define ResourceResolver.<br>
 * Standard implementation returned by {@link ResourceResolverFactory} handles
 * different {@link NamespaceResolver}s to redirect namespace resolution to
 * special URLs
 * 
 * @author noctarius
 * @since 0.0.1
 */
public interface ResourceResolver extends LSResourceResolver {

	/**
	 * Returns if warnings should be shown
	 * 
	 * @return Show warnings
	 */
	boolean isShowWarning();

	/**
	 * Sets if warnins should be shown
	 * 
	 * @param showWarning
	 *            Show warnings
	 */
	void setShowWarning(boolean showWarning);

	/**
	 * Registers a {@link NamespaceResolver} for this ResourceResolver
	 * 
	 * @param namespaceResolver
	 *            NamespaceResolver to add
	 */
	void registerNamespaceResolver(NamespaceResolver namespaceResolver);

	/**
	 * Removes a {@link NamespaceResolver} by given instance
	 * 
	 * @param namespaceResolver
	 *            NamespaceResolver instance to remove
	 */
	void unregisterNamespaceResolver(NamespaceResolver namespaceResolver);

	/**
	 * Removes a {@link NamespaceResolver} by given namespace URI
	 * 
	 * @param namespaceURI
	 *            Namespace of NamespaceResolver instance to remove
	 */
	void unregisterNamespaceResolver(String namespaceURI);
}