/*
 * 
 *  This file is part of XmlParser.
 *
 *  Foobar is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Foobar is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.sourceprojects.xmlparser;

import java.util.Dictionary;
import java.util.Hashtable;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.sourceprojects.xmlparser.internal.osgi.XmlParserOsgiServiceFactory;

/**
 * OSGi {@link BundleActivator} implementation for using {@link XmlParser} in OSGi environments.<br>
 * To retrieve an {@link XmlParser} instance on OSGi environments get a service reference to the {@link XmlParserOsgiFactory}.<br>
 * <pre>ServiceReference reference = context.getServiceReference(XmlParserOsgiFactory.class.getName());
		
if (reference == null)
	throw new XmlParserInitializationException("ServiceReference not found");
		
XmlParserOsgiFactory factory = (XmlParserOsgiFactory) context.getService(reference);
ServiceReference reference = context.getServiceReference(XmlParserOsgiFactory.class.getName());
		
if (reference == null)
	throw new XmlParserInitializationException("ServiceReference not found");
		
XmlParserOsgiFactory factory = (XmlParserOsgiFactory) context.getService(reference);
		
XmlParser<StringBuilder> parser = factory.newParserInstance();
ResourceResolver resolver = factory.newResourceResolverInstance();</pre>
 * 
 * @author noctarius
 * @since 0.0.5
 */
public class XmlParserActivator implements BundleActivator {
	private ServiceRegistration registration;

	/* (non-Javadoc)
	 * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
	 */
	@Override
	public void start(BundleContext context) throws Exception {
		Dictionary<String, String> properties = new Hashtable<String, String>();
		registration = context.registerService(XmlParserOsgiFactory.class
				.getName(), new XmlParserOsgiServiceFactory(), properties);
	}

	/* (non-Javadoc)
	 * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
	 */
	@Override
	public void stop(BundleContext context) throws Exception {
		registration.unregister();
	}

}
