/*
 * 
 *  This file is part of XmlParser.
 *
 *  Foobar is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Foobar is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
package org.sourceprojects.xmlparser;

import org.sourceprojects.xmlparser.exceptions.XmlParserInitializationException;

/**
 * Service interface for factory service in OSGi environments.
 * 
 * @author noctarius
 * @since 0.0.5
 */
public interface XmlParserOsgiFactory {
	/**
	 * Returns a new instance of the {@link XmlParser} on OSGi environments
	 * 
	 * @param <B>
	 *            Type of ContextObject to use
	 * @return A new instance of XmlParser
	 * @throws XmlParserInitializationException
	 *             If some exception occurs on initialization of the new
	 *             instance the exception is wrapped into a
	 *             {@link XmlParserInitializationException}
	 */
	<B> XmlParser<B> newParserInstance()
			throws XmlParserInitializationException;

	/**
	 * Returns a new instance of the {@link ResourceResolver} on OSGi
	 * environments
	 * 
	 * @return A new instance of ResourceResolver
	 * @throws XmlParserInitializationException
	 *             If some exception occurs on initialization of the new
	 *             instance the exception is wrapped into a
	 *             {@link XmlParserInitializationException}
	 */
	ResourceResolver newResourceResolverInstance()
			throws XmlParserInitializationException;

}
